==> haskell-ixset-typed-0.4.0.1-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ixset-typed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ixset-typed
version: 0.4.0.1
id: ixset-typed-0.4.0.1-4bNitdxw3vN2jRVfT2Wqh1
key: ixset-typed-0.4.0.1-4bNitdxw3vN2jRVfT2Wqh1
license: BSD-3-Clause
maintainer: Andres Löh <andres@well-typed.com>
author: Andres Löh, Happstack team, HAppS LLC
synopsis: Efficient relational queries on Haskell sets.
description:
    This Haskell package provides a data structure of sets that are indexed
    by potentially multiple indices.
    .
    Sets can be created, modified, and queried in various ways.
    .
    The package is a variant of the <https://hackage.haskell.org/package/ixset ixset>
    package. The ixset package makes use
    of run-time type information to find a suitable index on a query, resulting
    in possible run-time errors when no suitable index exists. In ixset-typed,
    the types of all indices available or tracked in the type system.
    Thus, ixset-typed should be safer to use than ixset, but in turn requires
    more GHC extensions.
    .
    At the moment, the two packages are relatively compatible. As a consequence
    of the more precise types, a few manual tweaks are necessary when switching
    from one to the other, but the interface is mostly the same.
category: Data Structures
abi: 716b9b8ad38c74a5b716509e36dd5c98
exposed: True
exposed-modules:
    Data.IxSet.Typed Data.IxSet.Typed.Ix
import-dirs: /usr/lib/ghc-8.6.4/site-local/ixset-typed-0.4.0.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/ixset-typed-0.4.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/ixset-typed-0.4.0.1
hs-libraries: HSixset-typed-0.4.0.1-4bNitdxw3vN2jRVfT2Wqh1
depends:
    base-4.12.0.0 containers-0.6.0.1 deepseq-1.4.4.0
    safecopy-0.9.4.3-AziztHi3LwP78GBwQYJvV6
    syb-0.7-KRW1LCxdMiCJrmhxCvzo37 template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-ixset-typed/html/ixset-typed.haddock
haddock-html: /usr/share/doc/haskell-ixset-typed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ixset-typed-0.4.0.1-19-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ixset-typed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ixset-typed
version: 0.4.0.1
id: ixset-typed-0.4.0.1-JgBwi5xWGew1ZWLQRrK9B3
key: ixset-typed-0.4.0.1-JgBwi5xWGew1ZWLQRrK9B3
license: BSD-3-Clause
maintainer: Andres Löh <andres@well-typed.com>
author: Andres Löh, Happstack team, HAppS LLC
synopsis: Efficient relational queries on Haskell sets.
description:
    This Haskell package provides a data structure of sets that are indexed
    by potentially multiple indices.
    .
    Sets can be created, modified, and queried in various ways.
    .
    The package is a variant of the <https://hackage.haskell.org/package/ixset ixset>
    package. The ixset package makes use
    of run-time type information to find a suitable index on a query, resulting
    in possible run-time errors when no suitable index exists. In ixset-typed,
    the types of all indices available or tracked in the type system.
    Thus, ixset-typed should be safer to use than ixset, but in turn requires
    more GHC extensions.
    .
    At the moment, the two packages are relatively compatible. As a consequence
    of the more precise types, a few manual tweaks are necessary when switching
    from one to the other, but the interface is mostly the same.
category: Data Structures
abi: 3fb080ee77048c9c29e00c4330b9420f
exposed: True
exposed-modules:
    Data.IxSet.Typed Data.IxSet.Typed.Ix
import-dirs: /usr/lib/ghc-8.6.5/site-local/ixset-typed-0.4.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/ixset-typed-0.4.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/ixset-typed-0.4.0.1
hs-libraries: HSixset-typed-0.4.0.1-JgBwi5xWGew1ZWLQRrK9B3
depends:
    base-4.12.0.0 containers-0.6.0.1 deepseq-1.4.4.0
    safecopy-0.9.4.3-IeE5vFZQ9LWHj7PlcmqnQy
    syb-0.7-KRW1LCxdMiCJrmhxCvzo37 template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-ixset-typed/html/ixset-typed.haddock
haddock-html: /usr/share/doc/haskell-ixset-typed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
